'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var stimulus = require('stimulus');

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}
class _class extends stimulus.Controller {
  connect() {
    this.hiddenClass = this.data.get('hiddenClass') || 'hidden';
  }

  toggle() {
    this.itemTargets.forEach(item => {
      item.classList.toggle(this.hiddenClass);
    });
  }

  show() {
    this.itemTargets.forEach(item => {
      item.classList.remove(this.hiddenClass);
    });
  }

  hide() {
    this.itemTargets.forEach(item => {
      item.classList.add(this.hiddenClass);
    });
  }

}

_defineProperty(_class, "targets", ['item']);

function _defineProperty$1(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}
class _class$1 extends stimulus.Controller {
  add(e) {
    e.preventDefault();
    const content = this.templateTarget.innerHTML.replace(/NEW_RECORD/g, new Date().getTime());
    this.targetTarget.insertAdjacentHTML('beforebegin', content);
  }

}

_defineProperty$1(_class$1, "targets", ['target', 'template']);

function _defineProperty$2(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}
class _class$2 extends stimulus.Controller {
  toggle(e) {
    e.preventDefault();
    this.checkboxTargets.forEach(checkbox => {
      checkbox.checked = e.target.checked;
    });
  }

}

_defineProperty$2(_class$2, "targets", ['checkbox']);

class index extends stimulus.Controller {
  replace(event) {
    event.preventDefault();
    const [,, xhr] = event.detail;
    this.element.innerHTML = xhr.response;
  }

}

class index$1 extends stimulus.Controller {
  connect() {
    this.data.has('lazyLoading') ? this.lazyLoad() : this.load();
  }

  disconnect() {
    this.stopRefreshing();
  }

  load() {
    this.fetch();

    if (this.data.has('refreshInterval')) {
      this.startRefreshing();
    }
  }

  lazyLoad() {
    const options = {
      threshold: this.data.get('lazyLoadingThreshold') || 0,
      rootMargin: this.data.get('lazyLoadingRootMargin') || '0px'
    };
    const observer = new IntersectionObserver((entries, observer) => {
      entries.forEach(entry => {
        if (entry.isIntersecting) {
          this.load();
          observer.unobserve(entry.target);
        }
      });
    }, options);
    observer.observe(this.element);
  }

  fetch() {
    fetch(this.data.get('url')).then(response => response.text()).then(html => {
      this.element.innerHTML = html;
    });
  }

  startRefreshing() {
    this.refreshTimer = setInterval(() => {
      this.fetch();
    }, this.data.get('refreshInterval'));
  }

  stopRefreshing() {
    if (this.refreshTimer) {
      clearInterval(this.refreshTimer);
    }
  }

}

function debounce(callback, delay) {
  let timeout;
  return (...args) => {
    const context = this;
    clearTimeout(timeout);
    timeout = setTimeout(() => callback.apply(context, args), delay);
  };
}

class index$2 extends stimulus.Controller {
  connect() {
    this.element.style.overflow = 'hidden';
    const delay = this.data.get('resizeDebounceDelay') || 100;
    this.autogrow = this.autogrow.bind(this);
    this.onResize = delay > 0 ? debounce(this.autogrow, delay) : this.autogrow;
    this.autogrow();
    this.element.addEventListener('input', this.autogrow);
    window.addEventListener('resize', this.onResize);
  }

  disconnect() {
    window.removeEventListener('resize', this.onResize);
  }

  autogrow() {
    this.element.style.height = 'auto'; // Force re-print before calculating the scrollHeight value.

    this.element.style.height = `${this.element.scrollHeight}px`;
  }

}

exports.CheckboxSelectAll = _class$2;
exports.ContentLoader = index$1;
exports.NestedForm = _class$1;
exports.Remote = index;
exports.Reveal = _class;
exports.TextareaAutogrow = index$2;
//# sourceMappingURL=index.js.map
